@@ -1,4 +1,4 @@
-#!/usr/bin/python22
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
 #  Copyright (c) 2016 Red Hat, Inc. <http://www.redhat.com>
@@ -13,7 +13,10 @@
 from __future__ import print_function
 import sys
 import signal
-import SocketServer
+try:
+    import socketserver
+except ImportError:
+    import SocketServer as socketserver
 import socket
 from argparse import ArgumentParser, RawDescriptionHelpFormatter
 
@@ -46,7 +49,7 @@ class GlusterEventsRequestHandler(SocketServer.BaseRequestHandler):
             logger.warn("Unable to parse Event {0}".format(data))
             return
 
-        for k, v in data_dict.iteritems():
+        for k, v in data_dict.items():
             try:
                 if k in AUTO_BOOL_ATTRIBUTES:
                     data_dict[k] = boolify(v)
